@@ -1,6 +1,6 @@
 from django import forms
 from edc_action_item.forms.action_item_form_mixin import ActionItemFormMixin
-from edc_form_validators.form_validator_mixin import FormValidatorMixin
+from edc_form_validators.form_validator_mixins import FormValidatorMixin
 from edc_sites.forms import SiteModelFormMixin
 
 from ..models import Ltfu
